@@ -38,10 +38,12 @@ from .getCardByCardNumber import getCardByCardNumber
 from .getAccountsHeld import getAccountsHeld
 from .getAccount import getAccountById
 from .getAccountTransactions import getAccountTransactions
+from .getViews import getViewsByProvider
 from .getCustomers import getCustomers
 from .deleteBranches import deleteBranches
 from .deleteCardById import deleteCardById
 from .getUserIdByUsername import getUserIdByUsername
+from .getUsers import getUsers
 import pprint
 
 @click.group()
@@ -126,6 +128,15 @@ def getuser():
   else:
     exit(req.text)
 
+@cli.command(help="😃 Get all users")
+def getusers():
+  req = getUsers();
+  if req.status_code == 200:
+    pp = pprint.PrettyPrinter(width=41, compact=True)
+    click.echo(pp.pprint(json.loads(req.text)))
+  else:
+    exit(req.txt)
+
 @cli.command(help="📋 Get your user id")
 def getuserid():
   req = getUserId()
@@ -362,6 +373,19 @@ def addview(bank_id, account_id, name, description, metadata_view,
   else:
     exit(req.text)
 
+@cli.command(help="🧐 Get views by provider")
+@click.option('--bank-id', default="gh.29.uk.x", prompt=True)
+@click.option('--account-id', prompt=True)
+@click.option('--provider', prompt=True)
+@click.option('--provider-id', prompt=True)
+def getviews(bank_id, account_id, provider, provider_id):
+  req = getViewsByProvider(bank_id=bank_id, account_id=account_id, 
+                          provider=provider, provider_id=provider_id)
+  if req.status_code == 201 or req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
 @cli.command(help="🔗 Link user to a customer")
 @click.option('--bank-id', default="gh.29.uk.x", prompt=True)
 @click.option('--user-id', required=True, prompt=True)
